@@ -14,6 +14,8 @@ from numpy import *
 # import statistics
 import io
 import base64
+from datetime import datetime as dt
+import time
 
 # Effective Rainfall Generation   
 # # Primary Inputs (required)
@@ -347,7 +349,10 @@ def greenampt(thetai, thetas, Psi, K, dti, nin, dd, i, iyesno, ss1, ss2, ss3):
     plt.rcParams["font.family"]="sans-serif"
     plt.rcParams['font.sans-serif'] = ['SimHei']
     plt.rcParams['axes.unicode_minus'] = False
-    plt.savefig('greenampt.png')
+    todayis = dt.utcnow()
+    d1 = todayis.strftime("%Y%m%d%H%M%S")
+    plt.savefig(f'pichistory/{d1}-greenampt.png',dpi = 300)
+    plt.savefig(f'var/www/flaskapp/pichistory/{d1}-greenampt.png',dpi = 300)
     # plt.show()
     #mpl.rcParams['axes.unicode_minus'] = False
     #matplotlib.rc('font', family='FangSong')
