@@ -14,6 +14,8 @@ import math
 import statistics
 import io
 import base64
+from datetime import datetime as dt
+import time
 
 # Reference Usage
 # if request.method == "POST":
@@ -397,7 +399,10 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         plt.rcParams["font.family"]="sans-serif"
         plt.rcParams['font.sans-serif'] = ['SimHei']
         plt.rcParams['axes.unicode_minus'] = False
-        plt.savefig('gumbel.png')
+        todayis = dt.utcnow()
+        d1 = todayis.strftime("%Y%m%d%H%M%S")
+        plt.savefig(f'pichistory/{d1}-gumbel.png',dpi = 300)
+        plt.savefig(f'var/www/flaskapp/pichistory/{d1}-gumbel.png',dpi = 300)
         img = io.BytesIO()
         plt.savefig(img, format='png')
         img.seek(0)
