@@ -16,6 +16,8 @@ import base64
 import PyQt5
 import seaborn as sns
 from decimal import Decimal
+from datetime import datetime as dt
+import time
 
 
 def data_conv(data):
@@ -710,7 +712,10 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     plt.rcParams["font.family"]="sans-serif"
     plt.rcParams['font.sans-serif'] = ['SimHei']
     plt.rcParams['axes.unicode_minus'] = False
-    plt.savefig('wavespectra.png')
+    todayis = dt.utcnow()
+    d1 = todayis.strftime("%Y%m%d%H%M%S")
+    plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
+    plt.savefig(f'var/www/flaskapp/pichistory/{d1}-wavespectra.png',dpi = 300)
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
